<?php 
/**
 * Subscribe section
 *
 * This is the template for the content of subscribe section
 *
 * @package Theme Palace
 * @subpackage Corporate Education Pro
 * @since Corporate Education Pro 1.0
 */
if ( ! function_exists( 'corporate_education_pro_add_subscribe_section' ) ) :
    /**
    * Add subscribe section
    *
    *@since Corporate Education Pro 1.0
    */
    function corporate_education_pro_add_subscribe_section() {
        $options = corporate_education_pro_get_theme_options();

        // Check if subscribe is enabled
        $enable_subscribe = apply_filters( 'corporate_education_pro_section_status', true, 'subscribe_enable' );

        if ( true !== $enable_subscribe || ! class_exists( 'Jetpack' ) || ! Jetpack::is_module_active( 'subscriptions' ) ) {
            return false;
        }

        // Render subscribe section now.
        corporate_education_pro_render_subscribe_section();
    }
endif;
add_action( 'corporate_education_pro_primary_content_action', 'corporate_education_pro_add_subscribe_section', 100 );

if ( ! function_exists( 'corporate_education_pro_render_subscribe_section' ) ) :
    /**
    * Start subscribe section
    *
    * @return string subscribe content
    * @since Corporate Education Pro 1.0
    *
    */
    function corporate_education_pro_render_subscribe_section() {
        $options    = corporate_education_pro_get_theme_options();
        $background = ! empty( $options['subscribe_image'] ) ? $options['subscribe_image'] : get_template_directory_uri() . '/assets/uploads/background-01.jpg';
        $title      = ! empty( $options['subscribe_title'] ) ? $options['subscribe_title'] : '';
        $sub_title  = ! empty( $options['subscribe_sub_title'] ) ? $options['subscribe_sub_title'] : '';
        $btn_label  = ! empty( $options['subscribe_btn_label'] ) ? $options['subscribe_btn_label'] : esc_html__( 'Subscribe Now', 'corporate-education-pro' );
        $message    = ! empty( $options['subscribe_success_message'] ) ? $options['subscribe_success_message'] : esc_html__( 'Success! An email was just sent to confirm your subscription. Please find the email now and click ( Confirm Follow ) to start subscribing.', 'corporate-education-pro' );
        ?>
        <section id="subscribe-newsletter" class="subscribe page-section parallax" style="background-image:url('<?php echo esc_url( $background ); ?>')" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="black-overlay"></div>
            <div class="wrapper">
                    <?php
                    $subscription_shortcode = '[jetpack_subscription_form title="' . esc_html( $title ) . '" subscribe_text="' . esc_html( $sub_title ) . '" subscribe_button="' . esc_html( $btn_label ) . '" show_subscribers_total="0"]';
                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) );
                    ?>
            </div><!-- .wrapper -->
        </section><!-- #subscribe-newsletter -->
    <?php }
endif;
